==> novprog_3.1.7.orig.tar.gz: novprog-3.1.7/translations/novprog_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Bar</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln woord</numerusform>
            <numerusform>%Ln woorden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Applicatietaal selecteren:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeemtaal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notitie</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>NovelDialog</name>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Goals</source>
        <translation>Doelen</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N.V.T.</translation>
    </message>
    <message>
        <source>Date Range</source>
        <translation>Datumbereik</translation>
    </message>
    <message>
        <source>Word Count</source>
        <translation>Woordenteller</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totaal:</translation>
    </message>
    <message>
        <source>Daily:</source>
        <translation>Dagelijks:</translation>
    </message>
    <message>
        <source>Start On:</source>
        <translation>Beginnen op:</translation>
    </message>
    <message>
        <source>End On:</source>
        <translation>Eindigen op:</translation>
    </message>
    <message>
        <source>Start At:</source>
        <translation>Beginnen bij:</translation>
    </message>
    <message>
        <source>Add Novel</source>
        <translation>Roman toevoegen</translation>
    </message>
    <message>
        <source>Edit Novel</source>
        <translation>Roman bewerken</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>A novel already exists with that name.</source>
        <translation>Er bestaat al een roman met die naam.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Novel Progress</source>
        <translation>Voortgang van roman</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Totaal</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Dagelijks</translation>
    </message>
    <message>
        <source>Word count:</source>
        <translation>Woordenteller:</translation>
    </message>
    <message>
        <source>&amp;Novel</source>
        <translation>&amp;Roman</translation>
    </message>
    <message>
        <source>&amp;New Novel</source>
        <translation>&amp;Nieuwe roman</translation>
    </message>
    <message>
        <source>&amp;Edit Novel</source>
        <translation>Roman &amp;bewerken</translation>
    </message>
    <message>
        <source>&amp;Delete Novel</source>
        <translation>Roman &amp;verwijderen</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerken</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwijderen</translation>
    </message>
    <message>
        <source>Delete novel?</source>
        <translation>Wilt u de roman verwijderen?</translation>
    </message>
    <message>
        <source>Delete progress for the novel &apos;%1&apos;?</source>
        <translation>Wilt u de voortgang van roman &apos;%1&apos; verwijderen?</translation>
    </message>
    <message>
        <source>This action cannot be undone.</source>
        <translation>Deze actie kan niet ongedaan worden gemaakt.</translation>
    </message>
</context>
</TS>

==> novprog_3.2.0.orig.tar.gz: novprog-3.2.0/translations/novprog_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Bar</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln woord</numerusform>
            <numerusform>%Ln woorden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Kies de programmataal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeemtaal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart het programma om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>NovelDialog</name>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Goals</source>
        <translation>Doelen</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>n.v.t.</translation>
    </message>
    <message>
        <source>Date Range</source>
        <translation>Datumbereik</translation>
    </message>
    <message>
        <source>Word Count</source>
        <translation>Woordenteller</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totaal:</translation>
    </message>
    <message>
        <source>Daily:</source>
        <translation>Dagelijks:</translation>
    </message>
    <message>
        <source>Start On:</source>
        <translation>Beginnen op:</translation>
    </message>
    <message>
        <source>End On:</source>
        <translation>Eindigen op:</translation>
    </message>
    <message>
        <source>Start At:</source>
        <translation>Beginnen bij:</translation>
    </message>
    <message>
        <source>Add Novel</source>
        <translation>Verhaal toevoegen</translation>
    </message>
    <message>
        <source>Edit Novel</source>
        <translation>Verhaal bewerken</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>A novel already exists with that name.</source>
        <translation>Er is al een verhaal met die naam.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Novel Progress</source>
        <translation>Schrijfvoortgang</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Totaal</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Dagelijks</translation>
    </message>
    <message>
        <source>Word count:</source>
        <translation>Woordenteller:</translation>
    </message>
    <message>
        <source>&amp;New Novel</source>
        <translation>&amp;Nieuw verhaal</translation>
    </message>
    <message>
        <source>&amp;Edit Novel</source>
        <translation>Verhaal b&amp;ewerken</translation>
    </message>
    <message>
        <source>&amp;Delete Novel</source>
        <translation>Verhaal verwij&amp;deren</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Novel</source>
        <translation>&amp;Verhaal</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>B&amp;ewerken</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Verwij&amp;deren</translation>
    </message>
    <message>
        <source>Delete novel?</source>
        <translation>Wilt u het verhaal verwijderen?</translation>
    </message>
    <message>
        <source>Delete progress for the novel &apos;%1&apos;?</source>
        <translation>Wilt u de voortgang van ‘%1’ verwijderen?</translation>
    </message>
    <message>
        <source>This action cannot be undone.</source>
        <translation>Deze actie kan niet ongedaan worden gemaakt.</translation>
    </message>
    <message>
        <source>Set words written today</source>
        <translation>Stel het aantal vandaag geschreven woorden in</translation>
    </message>
    <message>
        <source>Words written today:</source>
        <translation>Aantal vandaag geschreven woorden:</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>A wordcount graphing program</source>
        <translation>Een programma voor het in kaart brengen van het aantal woorden</translation>
    </message>
</context>
</TS>
